@@ -25,6 +25,7 @@ __all__ = (
     "ListHumanLoopsPaginatorName",
     "SortOrderType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -313,3 +314,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_human_loops"]
